==> nomachine-7.6.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXPaths.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXPaths::BEGIN{package NXPaths;no warnings;require Common::NXPaths;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x50\x61\x74\x68\x73"->import};}package
 NXPaths;no warnings;require Common::NXFile;sub getServerLogDir{(my $LogDir=((((
$GLOBAL::VAR_ROOT.$GLOBAL::DIRECTORY_SLASH)."\x6c\x6f\x67").
$GLOBAL::DIRECTORY_SLASH)."\x6e\x78\x73\x65\x72\x76\x65\x72"));return ($LogDir);
}sub getNodeRootDirectory{(my $directory=
Common::NXPaths::getNodeRootDirectoryPath ());if ((not (Common::NXFile::isExists
 ($directory)))){Logger::debug (((
"\x4e\x6f\x64\x65\x20\x72\x6f\x6f\x74\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e\x20\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x61\x74\x20"
.$directory)."\x2e"));my ($createDirectoryError);if ((
Common::NXPaths::createNodeRootDirectory ((\$createDirectoryError),$directory)==
(0x0861+ 5075-0x1c34))){main::checkin_session_dir (undef);
main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x61\x6e\x6e\x6f\x74\x43\x72\x65\x61\x74\x65\x57\x6f\x72\x6b\x69\x6e\x67\x44\x69\x72\x65\x63\x74\x6f\x72\x79"
,$directory,$createDirectoryError);}}return ($directory);}sub 
__pathToEffectiveUserDirectory{return (get_user_nx_dir ());}sub 
__getEffectiveUser{return (Common::NXCore::getEffectiveUsername ());}sub 
__getNXDirectoryForEffectiveUser{(my $directory=__pathToEffectiveUserDirectory 
());if ((not (Common::NXFile::directoryExists ($directory)))){(my $user=
__getEffectiveUser ());Logger::debug (((((
"\x27\x2e\x6e\x78\x27\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20\x66\x6f\x72\x20\x65\x66\x66\x65\x63\x74\x69\x76\x65\x20\x75\x73\x65\x72\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e\x20\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x61\x74\x20"
.$directory)."\x20\x66\x6f\x72\x20").$user)."\x2e"));my ($createDirectoryError);
if ((Common::NXPaths::createAccessibleForUserDirectory ((\$createDirectoryError)
,$directory,$user)==(0x1392+ 1013-0x1787))){Logger::error (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x6e\x78\x63\x6c\x69\x65\x6e\x74\x20\x77\x6f\x72\x6b\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20\x27"
.$directory)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20\x27").
$createDirectoryError)."\x27"));main::clean_and_die (
"\x65\x47\x55\x49\x43\x61\x6e\x6e\x6f\x74\x43\x72\x65\x61\x74\x65\x57\x6f\x72\x6b\x69\x6e\x67\x44\x69\x72\x65\x63\x74\x6f\x72\x79"
,$directory,$createDirectoryError);}}return ($directory);}sub 
getClientMonitorRootDirectory{return (__getNXDirectoryForEffectiveUser ());}sub 
getClientMonitorNxHomeDirectory{return (__getNXDirectoryForEffectiveUser ());}
sub getNxConfigPath{return (__getNXDirectoryForEffectiveUser ());}sub 
get_user_nx_dir{return (((Common::NXPaths::getEffectiveUserHomeDirectory ().
$GLOBAL::DIRECTORY_SLASH)."\x2e\x6e\x78"));}sub 
getClientMonitorSessionDirBaseOnLongID{(my $longSessionId=shift (@_));(my $path=
(shift (@_)||getClientMonitorRootDirectory ()));return (((($path.
$GLOBAL::DIRECTORY_SLASH).$GLOBAL::ClientDirectoryPrefix).$longSessionId));}sub 
longClientMonitorPathToTerminateDir{(my $longSessionId=shift (@_));(my $path=(
shift (@_)||getClientMonitorRootDirectory ()));return ((((($path.
$GLOBAL::DIRECTORY_SLASH)."\x54\x2d").$GLOBAL::ClientDirectoryPrefix).
$longSessionId));}sub longClientMonitorPathToFailedDir{(my $longSessionId=shift 
(@_));(my $path=(shift (@_)||getClientMonitorRootDirectory ()));return (((((
$path.$GLOBAL::DIRECTORY_SLASH)."\x46\x2d").$GLOBAL::ClientDirectoryPrefix).
$longSessionId));}sub longSessionIdPathToAgentMDir{(my $longSessionId=shift (@_)
);(my $path=(shift (@_)||getNodeRootDirectory ()));return (((($path.
$GLOBAL::DIRECTORY_SLASH)."\x43\x2d").$longSessionId));}sub 
longSessionIdPathToTerminateDir{(my $longSessionId=shift (@_));(my $path=(shift 
(@_)||getNodeRootDirectory ()));return (((($path.$GLOBAL::DIRECTORY_SLASH).
"\x54\x2d\x43\x2d").$longSessionId));}sub longSessionIdPathToFailedDir{(my $longSessionId
=shift (@_));(my $path=(shift (@_)||getNodeRootDirectory ()));return (((($path.
$GLOBAL::DIRECTORY_SLASH)."\x46\x2d\x43\x2d").$longSessionId));}sub 
sessionDirPathToOptionsFile{(my $sessionDir=shift (@_));return ((($sessionDir.
$GLOBAL::DIRECTORY_SLASH)."\x6f\x70\x74\x69\x6f\x6e\x73"));}sub 
sessionDirPathToLocalXauthorityScript{(my $sessionDir=shift (@_));return (((
$sessionDir.$GLOBAL::DIRECTORY_SLASH).
"\x61\x75\x74\x68\x6f\x72\x69\x74\x79\x73\x63\x72\x69\x70\x74"));}sub 
sessionDirPathToLocalXauthorityFile{(my $sessionDir=shift (@_));return (((
$sessionDir.$GLOBAL::DIRECTORY_SLASH)."\x61\x75\x74\x68\x6f\x72\x69\x74\x79"));}
sub sessionDirPathToLocalSessionFile{(my $sessionDir=shift (@_));return (((
$sessionDir.$GLOBAL::DIRECTORY_SLASH)."\x73\x65\x73\x73\x69\x6f\x6e"));}sub 
sessionDirPathToAudioDir{(my $sessionDir=shift (@_));return ((($sessionDir.
$GLOBAL::DIRECTORY_SLASH)."\x61\x75\x64\x69\x6f"));}sub 
sessionDirPathToPulseNativeSocket{(my $sessionDir=shift (@_));(my $audioPath=
sessionDirPathToAudioDir ($sessionDir));return ((($audioPath.
$GLOBAL::DIRECTORY_SLASH)."\x6e\x61\x74\x69\x76\x65\x2e\x73\x6f\x63\x6b\x65\x74"
));}sub sessionDirPathToPulseCliSocket{(my $sessionDir=shift (@_));(my $audioPath
=sessionDirPathToAudioDir ($sessionDir));return ((($audioPath.
$GLOBAL::DIRECTORY_SLASH)."\x63\x6c\x69\x2e\x73\x6f\x63\x6b\x65\x74"));}sub 
runDirPath{(my $varDir=$GLOBAL::VAR_ROOT);return ((($varDir.
$GLOBAL::DIRECTORY_SLASH)."\x72\x75\x6e"));}sub nxdeviceDirPath{return (((
__getNXDirectoryForEffectiveUser ().$GLOBAL::DIRECTORY_SLASH).
"\x6e\x78\x64\x65\x76\x69\x63\x65"));}sub nxdeviceSessionDirPath{(my $sessionId=
shift (@_));(my $varDir=nxdeviceDirPath ());return (((($varDir.
$GLOBAL::DIRECTORY_SLASH)."\x44\x2d").$sessionId));}sub getAudioNativeSocketPath
{(my $display=shift (@_));(my $sessionId=shift (@_));(my $sessionDir=
nxdeviceSessionDirPath ((($display."\x2d").$sessionId)));(my $path=((
sessionDirPathToAudioDir ($sessionDir).$GLOBAL::DIRECTORY_SLASH).
"\x6e\x61\x74\x69\x76\x65\x2e\x73\x6f\x63\x6b\x65\x74"));return ($path);}sub 
getAudioInFifoPath{(my $display=shift (@_));(my $sessionId=shift (@_));(my $sessionDir
=nxdeviceSessionDirPath ((($display."\x2d").$sessionId)));(my $path=((
sessionDirPathToAudioDir ($sessionDir).$GLOBAL::DIRECTORY_SLASH).
"\x61\x75\x64\x69\x6f\x5f\x69\x6e\x2e\x66\x69\x66\x6f"));return ($path);}sub 
getVoiceOutFifoPath{(my $display=shift (@_));(my $sessionId=shift (@_));(my $sessionDir
=nxdeviceSessionDirPath ((($display."\x2d").$sessionId)));(my $path=((
sessionDirPathToAudioDir ($sessionDir).$GLOBAL::DIRECTORY_SLASH).
"\x76\x6f\x69\x63\x65\x5f\x6f\x75\x74\x2e\x66\x69\x66\x6f"));return ($path);}sub
 getMirrorPath{return (((((Common::NXPaths::getEffectiveUserHomeDirectory ().
$GLOBAL::DIRECTORY_SLASH)."\x2e\x6e\x78").$GLOBAL::DIRECTORY_SLASH).
"\x6d\x69\x72\x72\x6f\x72"));}sub 
getPathToSocketFileForPassDescriptorToAnotherNode{(my $sessionID=shift (@_));(my $path
=("\x2f\x74\x6d\x70\x2f\x73\x6f\x63\x6b\x65\x74\x2d".$sessionID));return ($path)
;}sub getPathToServerDB{(my $path=(((($GLOBAL::VAR_ROOT.$GLOBAL::DIRECTORY_SLASH
)."\x64\x62").$GLOBAL::DIRECTORY_SLASH)."\x73\x65\x72\x76\x65\x72"));return (
$path);}sub createAndCorrectUserNXDirectoryOnWindows{(my $nxDirectoryPath=shift 
(@_));(my $ref_errorName=shift (@_));if (($nxDirectoryPath eq (""))){return (
(0x1447+ 4085-0x243c));}if ((not (Common::NXPaths::makePath ($ref_errorName,
$nxDirectoryPath)))){return ((0x1be2+ 441-0x1d9b));}else{(my $change=
correctUserNXDirectoryPermissionsOnWindows ($nxDirectoryPath));return ($change);
}}sub correctTmpNXDirectoryPermissionsOnWindows{(my $nxDirectoryPath=shift (@_))
;if (($nxDirectoryPath eq (""))){($nxDirectoryPath=
Common::NXPaths::getFailbackHomeDirectoryPathFromNXTemp ());}if ((
Common::NXFile::setPermissionsFullForAllDirectory ($nxDirectoryPath)==(-
(0x0d6f+ 1107-0x11c1)))){return ((0x095d+ 4674-0x1b9f));}
Common::NXCore::setHiddenAttributeOnWindows ($nxDirectoryPath);return (
(0x0b00+ 5696-0x213f));}sub correctUserNXDirectoryPermissionsOnWindows{(my $nxDirectoryPath
=shift (@_));my ($error);if (($nxDirectoryPath eq (""))){($nxDirectoryPath=
Common::NXPaths::getNxDirectoryInHomeOfDesktopOwnerOnWindows ((\$error)));}if ((
(not (Common::NXFile::directoryExists ($nxDirectoryPath)))and defined ($error)))
{main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x43\x72\x65\x61\x74\x65\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x57\x69\x74\x68\x53\x79\x73\x74\x65\x6d\x45\x72\x72\x6f\x72"
,$nxDirectoryPath,$error);}if (($nxDirectoryPath eq 
Common::NXPaths::getFailbackHomeDirectoryPathFromNXTemp ())){return (
correctTmpNXDirectoryPermissionsOnWindows ($nxDirectoryPath));}(my ($user,$tmp)=
NXLocalSession::getDisplayOwnerAndType ());if (($user eq 
"\x64\x65\x74\x61\x63\x68\x65\x64")){return ((0x0bba+ 3188-0x182e));}if ((
Common::NXFile::setPermissionsInheritAndAllowTakeOwnershipIfNeeded (
$nxDirectoryPath)==(-(0x07dd+ 3382-0x1512)))){return ((0x033a+ 4330-0x1424));}
Common::NXCore::setHiddenAttributeOnWindows ($nxDirectoryPath);if ((($user eq 
(""))and Common::NXCore::isEffectiveUsernameSystem ())){($user=
"\x53\x59\x53\x54\x45\x4d");}if ((Common::NXFile::setOwnershipForUser (
$nxDirectoryPath,$user)==(-(0x0861+ 3954-0x17d2)))){return (
(0x1380+ 3504-0x2130));}return ((0x0d88+ 1074-0x11b9));}sub getLogoutScript{
return ((((((($GLOBAL::NODE_ROOT.$GLOBAL::DIRECTORY_SLASH).
"\x73\x63\x72\x69\x70\x74\x73").$GLOBAL::DIRECTORY_SLASH)."\x65\x6e\x76").
$GLOBAL::DIRECTORY_SLASH).
"\x66\x6f\x72\x63\x65\x6c\x6f\x67\x6f\x75\x74\x2e\x73\x68"));}return (
(0x12b4+ 3860-0x21c7));

==> nomachine-7.7.4-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXPaths.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXPaths::BEGIN{package NXPaths;no warnings;require Common::NXPaths;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x50\x61\x74\x68\x73"->import};}package
 NXPaths;no warnings;require Common::NXFile;sub getServerLogDir{(my $LogDir=((((
$GLOBAL::VAR_ROOT.$GLOBAL::DIRECTORY_SLASH)."\x6c\x6f\x67").
$GLOBAL::DIRECTORY_SLASH)."\x6e\x78\x73\x65\x72\x76\x65\x72"));return ($LogDir);
}sub getNodeRootDirectory{(my $directory=
Common::NXPaths::getNodeRootDirectoryPath ());if ((not (Common::NXFile::isExists
 ($directory)))){Logger::debug (((
"\x4e\x6f\x64\x65\x20\x72\x6f\x6f\x74\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e\x20\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x61\x74\x20"
.$directory)."\x2e"));my ($createDirectoryError);if ((
Common::NXPaths::createNodeRootDirectory ((\$createDirectoryError),$directory)==
(0x0dad+ 1863-0x14f4))){main::checkin_session_dir (undef);
main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x61\x6e\x6e\x6f\x74\x43\x72\x65\x61\x74\x65\x57\x6f\x72\x6b\x69\x6e\x67\x44\x69\x72\x65\x63\x74\x6f\x72\x79"
,$directory,$createDirectoryError);}}return ($directory);}sub 
__pathToEffectiveUserDirectory{return (get_user_nx_dir ());}sub 
__getEffectiveUser{return (Common::NXCore::getEffectiveUsername ());}sub 
__getNXDirectoryForEffectiveUser{(my $directory=__pathToEffectiveUserDirectory 
());if ((not (Common::NXFile::directoryExists ($directory)))){(my $user=
__getEffectiveUser ());Logger::debug (((((
"\x27\x2e\x6e\x78\x27\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20\x66\x6f\x72\x20\x65\x66\x66\x65\x63\x74\x69\x76\x65\x20\x75\x73\x65\x72\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e\x20\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x61\x74\x20"
.$directory)."\x20\x66\x6f\x72\x20").$user)."\x2e"));my ($createDirectoryError);
if ((Common::NXPaths::createAccessibleForUserDirectory ((\$createDirectoryError)
,$directory,$user)==(0x0778+ 441-0x0931))){Logger::error (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x6e\x78\x63\x6c\x69\x65\x6e\x74\x20\x77\x6f\x72\x6b\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20\x27"
.$directory)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20\x27").
$createDirectoryError)."\x27"));main::clean_and_die (
"\x65\x47\x55\x49\x43\x61\x6e\x6e\x6f\x74\x43\x72\x65\x61\x74\x65\x57\x6f\x72\x6b\x69\x6e\x67\x44\x69\x72\x65\x63\x74\x6f\x72\x79"
,$directory,$createDirectoryError);}}return ($directory);}sub 
getClientMonitorRootDirectory{return (__getNXDirectoryForEffectiveUser ());}sub 
getClientMonitorNxHomeDirectory{return (__getNXDirectoryForEffectiveUser ());}
sub getNxConfigPath{return (__getNXDirectoryForEffectiveUser ());}sub 
get_user_nx_dir{return (((Common::NXPaths::getEffectiveUserHomeDirectory ().
$GLOBAL::DIRECTORY_SLASH)."\x2e\x6e\x78"));}sub 
getClientMonitorSessionDirBaseOnLongID{(my $longSessionId=shift (@_));(my $path=
(shift (@_)||getClientMonitorRootDirectory ()));return (((($path.
$GLOBAL::DIRECTORY_SLASH).$GLOBAL::ClientDirectoryPrefix).$longSessionId));}sub 
longClientMonitorPathToTerminateDir{(my $longSessionId=shift (@_));(my $path=(
shift (@_)||getClientMonitorRootDirectory ()));return ((((($path.
$GLOBAL::DIRECTORY_SLASH)."\x54\x2d").$GLOBAL::ClientDirectoryPrefix).
$longSessionId));}sub longClientMonitorPathToFailedDir{(my $longSessionId=shift 
(@_));(my $path=(shift (@_)||getClientMonitorRootDirectory ()));return (((((
$path.$GLOBAL::DIRECTORY_SLASH)."\x46\x2d").$GLOBAL::ClientDirectoryPrefix).
$longSessionId));}sub longSessionIdPathToAgentMDir{(my $longSessionId=shift (@_)
);(my $path=(shift (@_)||getNodeRootDirectory ()));return (((($path.
$GLOBAL::DIRECTORY_SLASH)."\x43\x2d").$longSessionId));}sub 
longSessionIdPathToTerminateDir{(my $longSessionId=shift (@_));(my $path=(shift 
(@_)||getNodeRootDirectory ()));return (((($path.$GLOBAL::DIRECTORY_SLASH).
"\x54\x2d\x43\x2d").$longSessionId));}sub longSessionIdPathToFailedDir{(my $longSessionId
=shift (@_));(my $path=(shift (@_)||getNodeRootDirectory ()));return (((($path.
$GLOBAL::DIRECTORY_SLASH)."\x46\x2d\x43\x2d").$longSessionId));}sub 
sessionDirPathToOptionsFile{(my $sessionDir=shift (@_));return ((($sessionDir.
$GLOBAL::DIRECTORY_SLASH)."\x6f\x70\x74\x69\x6f\x6e\x73"));}sub 
sessionDirPathToLocalXauthorityScript{(my $sessionDir=shift (@_));return (((
$sessionDir.$GLOBAL::DIRECTORY_SLASH).
"\x61\x75\x74\x68\x6f\x72\x69\x74\x79\x73\x63\x72\x69\x70\x74"));}sub 
sessionDirPathToLocalXauthorityFile{(my $sessionDir=shift (@_));return (((
$sessionDir.$GLOBAL::DIRECTORY_SLASH)."\x61\x75\x74\x68\x6f\x72\x69\x74\x79"));}
sub sessionDirPathToLocalSessionFile{(my $sessionDir=shift (@_));return (((
$sessionDir.$GLOBAL::DIRECTORY_SLASH)."\x73\x65\x73\x73\x69\x6f\x6e"));}sub 
sessionDirPathToAudioDir{(my $sessionDir=shift (@_));return ((($sessionDir.
$GLOBAL::DIRECTORY_SLASH)."\x61\x75\x64\x69\x6f"));}sub 
sessionDirPathToPulseNativeSocket{(my $sessionDir=shift (@_));(my $audioPath=
sessionDirPathToAudioDir ($sessionDir));return ((($audioPath.
$GLOBAL::DIRECTORY_SLASH)."\x6e\x61\x74\x69\x76\x65\x2e\x73\x6f\x63\x6b\x65\x74"
));}sub sessionDirPathToPulseCliSocket{(my $sessionDir=shift (@_));(my $audioPath
=sessionDirPathToAudioDir ($sessionDir));return ((($audioPath.
$GLOBAL::DIRECTORY_SLASH)."\x63\x6c\x69\x2e\x73\x6f\x63\x6b\x65\x74"));}sub 
runDirPath{(my $varDir=$GLOBAL::VAR_ROOT);return ((($varDir.
$GLOBAL::DIRECTORY_SLASH)."\x72\x75\x6e"));}sub nxdeviceDirPath{return (((
__getNXDirectoryForEffectiveUser ().$GLOBAL::DIRECTORY_SLASH).
"\x6e\x78\x64\x65\x76\x69\x63\x65"));}sub nxdeviceSessionDirPath{(my $sessionId=
shift (@_));(my $varDir=nxdeviceDirPath ());return (((($varDir.
$GLOBAL::DIRECTORY_SLASH)."\x44\x2d").$sessionId));}sub getAudioNativeSocketPath
{(my $display=shift (@_));(my $sessionId=shift (@_));(my $sessionDir=
nxdeviceSessionDirPath ((($display."\x2d").$sessionId)));(my $path=((
sessionDirPathToAudioDir ($sessionDir).$GLOBAL::DIRECTORY_SLASH).
"\x6e\x61\x74\x69\x76\x65\x2e\x73\x6f\x63\x6b\x65\x74"));return ($path);}sub 
getAudioInFifoPath{(my $display=shift (@_));(my $sessionId=shift (@_));(my $sessionDir
=nxdeviceSessionDirPath ((($display."\x2d").$sessionId)));(my $path=((
sessionDirPathToAudioDir ($sessionDir).$GLOBAL::DIRECTORY_SLASH).
"\x61\x75\x64\x69\x6f\x5f\x69\x6e\x2e\x66\x69\x66\x6f"));return ($path);}sub 
getVoiceOutFifoPath{(my $display=shift (@_));(my $sessionId=shift (@_));(my $sessionDir
=nxdeviceSessionDirPath ((($display."\x2d").$sessionId)));(my $path=((
sessionDirPathToAudioDir ($sessionDir).$GLOBAL::DIRECTORY_SLASH).
"\x76\x6f\x69\x63\x65\x5f\x6f\x75\x74\x2e\x66\x69\x66\x6f"));return ($path);}sub
 getMirrorPath{return (((((Common::NXPaths::getEffectiveUserHomeDirectory ().
$GLOBAL::DIRECTORY_SLASH)."\x2e\x6e\x78").$GLOBAL::DIRECTORY_SLASH).
"\x6d\x69\x72\x72\x6f\x72"));}sub 
getPathToSocketFileForPassDescriptorToAnotherNode{(my $sessionID=shift (@_));(my $path
=("\x2f\x74\x6d\x70\x2f\x73\x6f\x63\x6b\x65\x74\x2d".$sessionID));return ($path)
;}sub getPathToServerDB{(my $path=(((($GLOBAL::VAR_ROOT.$GLOBAL::DIRECTORY_SLASH
)."\x64\x62").$GLOBAL::DIRECTORY_SLASH)."\x73\x65\x72\x76\x65\x72"));return (
$path);}sub createAndCorrectUserNXDirectoryOnWindows{(my $nxDirectoryPath=shift 
(@_));(my $ref_errorName=shift (@_));if (($nxDirectoryPath eq (""))){return (
(0x1aaa+ 2179-0x232d));}if ((not (Common::NXPaths::makePath ($ref_errorName,
$nxDirectoryPath)))){return ((0x0d32+ 4597-0x1f27));}else{(my $change=
correctUserNXDirectoryPermissionsOnWindows ($nxDirectoryPath));return ($change);
}}sub correctTmpNXDirectoryPermissionsOnWindows{(my $nxDirectoryPath=shift (@_))
;if (($nxDirectoryPath eq (""))){($nxDirectoryPath=
Common::NXPaths::getFailbackHomeDirectoryPathFromNXTemp ());}if ((
Common::NXFile::setPermissionsFullForAllDirectory ($nxDirectoryPath)==(-
(0x181b+ 770-0x1b1c)))){return ((0x022b+ 978-0x05fd));}
Common::NXCore::setHiddenAttributeOnWindows ($nxDirectoryPath);return (
(0x0402+ 6790-0x1e87));}sub correctUserNXDirectoryPermissionsOnWindows{(my $nxDirectoryPath
=shift (@_));my ($error);if (($nxDirectoryPath eq (""))){($nxDirectoryPath=
Common::NXPaths::getNxDirectoryInHomeOfDesktopOwnerOnWindows ((\$error)));}if ((
(not (Common::NXFile::directoryExists ($nxDirectoryPath)))and defined ($error)))
{main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x43\x72\x65\x61\x74\x65\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x57\x69\x74\x68\x53\x79\x73\x74\x65\x6d\x45\x72\x72\x6f\x72"
,$nxDirectoryPath,$error);}if (($nxDirectoryPath eq 
Common::NXPaths::getFailbackHomeDirectoryPathFromNXTemp ())){return (
correctTmpNXDirectoryPermissionsOnWindows ($nxDirectoryPath));}(my ($user,$tmp)=
NXLocalSession::getDisplayOwnerAndType ());if (($user eq 
"\x64\x65\x74\x61\x63\x68\x65\x64")){return ((0x09ed+ 2311-0x12f4));}if ((
Common::NXFile::setPermissionsInheritAndAllowTakeOwnershipIfNeeded (
$nxDirectoryPath)==(-(0x0150+ 9234-0x2561)))){return ((0x08a3+ 6846-0x2361));}
Common::NXCore::setHiddenAttributeOnWindows ($nxDirectoryPath);if ((($user eq 
(""))and Common::NXCore::isEffectiveUsernameSystem ())){($user=
"\x53\x59\x53\x54\x45\x4d");}if ((Common::NXFile::setOwnershipForUser (
$nxDirectoryPath,$user)==(-(0x1b09+ 1866-0x2252)))){return (
(0x1283+ 1976-0x1a3b));}return ((0x113b+ 945-0x14eb));}sub getLogoutScript{
return ((((((($GLOBAL::NODE_ROOT.$GLOBAL::DIRECTORY_SLASH).
"\x73\x63\x72\x69\x70\x74\x73").$GLOBAL::DIRECTORY_SLASH)."\x65\x6e\x76").
$GLOBAL::DIRECTORY_SLASH).
"\x66\x6f\x72\x63\x65\x6c\x6f\x67\x6f\x75\x74\x2e\x73\x68"));}return (
(0x0446+ 1534-0x0a43));
